==> wawa-service-common-0.0.37-20180702.065638-2-sources.jar: cn/com/wawa/common/constants/ConfigKeyConstants.java <==
package cn.com.wawa.common.constants;

public class ConfigKeyConstants {
    /**
     * 活动推送消息的活动id
     */
    public static final String ACTIVITY_JPUSH_ACTIVITYIDS = "ACTIVITY_JPUSH_ACTIVITYIDS";
    /**
     * 具体活动的推送规则和内容
     */
    public static final String ACTIVITY_JPUSH_CONFIG = "ACTIVITY_JPUSH_CONFIG_%s";
    /**
     * 娃娃订单详情中的领取规则
     */
    public static final String WAWA_RECEIVE_RULE = "WAWA_RECEIVE_RULE_%s";

    public static final String CAUGHT_BROADCAST_MSG = "CAUGHT_BROADCAST_MSG";

    public static final String HOME_POPUP_ACTIVITY = "HOME_POPUP_ACTIVITY";

    //消防群token
    public static final String WARN_RECIVER = "WARN_RECIVER";

    //风控报警群
    public static final String DINGDING_WARN_RISK = "DINGDING_WARN_RISK";

    public static final String MINE_OVERWRITTING_COLOR="MINE_OVERWRITTING_COLOR";

    public static final String MY_PAGE_OVERWRITING_COLOR = "MY_PAGE_OVERWRITING_COLOR";

    //ios审核用户id
    public static final String IOS_REVIEW_USERID="IOS_REVIEW_USERID";
    //ios审核用户token
    public static final String IOS_REVIEW_TOKEN="IOS_REVIEW_TOKEN";
    /**
     * 已发货的用户,不再展示红字部分规则
     */
    public static final String WAWA_RECEIVE_RULE_DELIVERY="WAWA_RECEIVE_RULE_DELIVERY";

    /**
     * 强抓不中送机会
     */
    public static final String STRONG_GRAB_CHANCE = "STRONG_GRAB_CHANCE";
    public static final String STRONG_GRAB_CHANCE_NEW = "STRONG_GRAB_CHANCE_NEW";
    /**
     * 背景音乐url
     */
    public static final String MUSIC_URL = "MUSIC_URL";

    /**
     * 娃娃机故障告警群token
     */
    public static final String WAWA_FAULT = "WAWA_FAULT";

    /**
     * 发货提示消息配置
     */
    public static final String DELIVERY_HINT = "DELIVERY_HINT";

    /**
     * 钉钉发货提示消息配置
     */
    public static final String ARWARD_DELIVERY = "ARWARD_DELIVERY";

    /**
     * 抓取失败原因(mq发送)
     */
    public static final String CAUGHT_FAIL_MSG = "CAUGHT_FAIL_MSG";
    /**
     * 娃娃机数量监控执行时间配置
     */
    public static final String WAWA_NUM_MONITOR_KEY = "WAWA_NUM_MONITOR_KEY";

    public static final String ACCOUNT_CHANGE_DETAIL_SHOW_SWITCH = "ACCOUNT_CHANGE_DETAIL_SHOW_SWITCH";

    public static final String CENTER_MSG_TYPE_PIC = "CENTER_MSG_TYPE_PIC_%s";

    public static final String APPEAL_REJECT_MSG = "APPEAL_REJECT_CENTER_MSG";
    public static final String APPEAL_JUDGE_CATCHED_MSG = "APPEAL_JUDGE_CATCHED_CENTER_MSG";
    public static final String APPEAL_RETURN_COIN_MSG = "APPEAL_RETURN_COIN_CENTER_MSG";
    public static final String APPEAL_ADD_WAWA_NUM_MSG = "APPEAL_ADD_WAWA_NUM_CENTER_MSG";
    public static final String APPEAL_OTHER_MSG = "APPEAL_OTHER_CENTER_MSG";
    public static final String RED_PACKAGE_WILL_EXPIRE_MSG = "RED_PACKAGE_WILL_EXPIRE_CENTER_MSG";
    public static final String DELIVERY_ALREADY_MSG_CONTENT = "DELIVERY_ALREADY_MSG_CONTENT";
    public static final String DELIVERY_SIGNIN_MSG_CONTENT = "DELIVERY_SIGNIN_MSG_CONTENT";

    /**
     * 拼团
     */
    public static final String GROUP_BOOK_JOIN_SUC_SMS = "GROUP_BOOK_JOIN_SUC_SMS";
    public static final String GROUP_BOOK_ALERT_SMS = "GROUP_BOOK_ALERT_SMS";
    public static final String GROUP_BOOK_SUC_SMS = "GROUP_BOOK_SUC_SMS";
    public static final String GROUP_BOOK_FAIL_SMS = "GROUP_BOOK_FAIL_SMS";
    public static final String GROUP_BOOK_NEW_USER_NO_APP_SMS = "GROUP_BOOK_NEW_USER_NO_APP_SMS";

    public static final String GROUP_BOOK_ALERT_CENTER_MSG = "GROUP_BOOK_ALERT_CENTER_MSG";
    public static final String GROUP_BOOK_SUC_CENTER_MSG = "GROUP_BOOK_SUC_CENTER_MSG";
    public static final String GROUP_BOOK_FAIL_CENTER_MSG = "GROUP_BOOK_FAIL_CENTER_MSG";

    public static final String GROUP_BOOK_SUC_JPUSH = "GROUP_BOOK_SUC_JPUSH";

    /**
     * 排行榜活动时间配置  临时
     */
    public static final String RANK_LIST = "RANK_LIST";

    public static final String RANK_AWARD_CENTER_MSG = "RANK_AWARD_CENTER_MSG";

    /**
     * 失败后加积分版本
     */
    public static final String ADD_CREDITS_VERSION ="ADD_CREDITS_VERSION";

    public static final String ADD_CREDITS_CAUGHT_FAIL_MSG="ADD_CREDITS_CAUGHT_FAIL_MSG";

    public static final String FAST_DIALOG_CONFIG="FAST_DIALOG_CONFIG";

    /**
     * 充值送的红包的档位
     */
    public static final String GUARANTEE_V3_WAWA_CONFIG="GUARANTEE_V3_WAWA_CONFIG";
    /**
     * 卡展示规则
     */
    public static final String CARD_SHOW_RULE="CARD_SHOW_RULE";

    public static final String CARD_JPUSH_CONFIG = "CARD_JPUSH_CONFIG";
    public static final String CARD_FLOOR_CONFIG = "CARD_FLOOR_CONFIG";
    public static final String CARD_SHOW_EXPIRED_PIC = "CARD_SHOW_EXPIRED_PIC";

    public static final String GET_TITLE = "GET_TITLE";

    public static final String CONFIG_GMT_CREATE = "CONFIG_GMT_CREATE";

    public static final String WAWA_PAST_DUE = "WAWA_PAST_DUE";

    /**
     * 限时玩法
     */
    public static final String TIME_LIMIT_CONFIG = "TIME_LIMIT_CONFIG";
    public static final String CHARGE_ABTEST="CHARGE_ABTEST";

    /**
     * 限时玩法 风控规则
     */
    public static final String TIME_LIMIT_RISK_MANAGE = "TIME_LIMIT_RISK_MANAGE";

    /**
     * erp订单区分查询配置key
     */
    public static final String ERP_ORDER_SHOP_CONFIG = "ERP_ORDER_SHOP_CONFIG";

    public static final String FIRST_CHARGE_COUNTDOWN = "FIRST_CHARGE_COUNTDOWN";

    /**
     * 豪礼奖励系统消息模板
     */
    public static final String ACTIVITY_SOLID_AWARD_MSG = "ACTIVITY_SOLID_AWARD_MSG";
    public static final String ACTIVITY_DAILY_AWARD_MSG = "ACTIVITY_DAILY_AWARD_MSG";
    public static final String ACTIVITY_ACTIVE_AWARD_MSG = "ACTIVITY_ACTIVE_AWARD_MSG";

    /**
     * erp取消订单相关报警
     */
    public static final String ERP_CANCELL_MSG = "ERP_CANCELL_MSG";

    /**
     *vip等级晋升消息
     */
    public static final String VIP_PROMOTION_MSG = "VIP_PROMOTION_MSG";
    /**
     *vip等级晋升站内信中图片地址key值模板
     */
    public static final String VIP_PROMOTION_IMG = "VIP_PROMOTION_IMG_VIP%S";

    /**
     * 发送填写vip微信号站内信模板
     */
    public static final String WRITE_VIP_WXNO_MSG = "WRITE_VIP_WXNO_MSG";

    public static final String APPEAL_HANDLE_WARM_CONFIG = "APPEAL_HANDLE_WARM_CONFIG";

    /**
     * 游戏失败赠送乐豆奖励配置信息
     */
    public static final String REWARD_CREDIS_CONFIG = "REWARD_CREDIS_CONFIG";

    /**
     * 限时玩法-1v1  匹配场等级
     */
    public static final String TIME_LIMIT_PK_LEVEL = "TIME_LIMIT_PK_LEVEL";
    /**
     * 限时玩法-1v1  玩法介绍页
     */
    public static final String PK_1V1_IMG_CONFIG = "PK_1V1_IMG_CONFIG";

    public static final String ADD_COIN = "ADD_COIN";
    /**
     * 限时玩法-1v1  初级场金额
     */
    public static final String BATTLE_JUNIOR_PRICE = "BATTLE_JUNIOR_PRICE";

    /**
     * 限时pk玩法上线时间key,用于甄别 在上线时间之后的为新用户,需要走abtest逻辑
     */
    public static final String LIMIT_PK_ONLINE_TIME = "LIMIT_PK_ONLINE_TIME";

    /**
     * VIP专区所对应的分类id
     */
    public static final String VIP_CATEGORY_ID_CONFIG = "VIP_CATEGORY_ID_CONFIG";

    /**
     * 移动端充值url
     */
    public static final String MOBILE_PAY_URL = "MOBILE_PAY_URL";

    /**
     * vip等级特权：更多icon配置信息
     */
    public static final String VIP_MORE_PRIVILEGE_CONFIG = "VIP_MORE_PRIVILEGE_CONFIG";

    /**
     * vip等级特权九宫格请求地址配置信息
     */
    public static final String VIP_PRIVILEGE_DEC_H5_URL = "VIP_PRIVILEGE_DEC_H5_URL";

    /**
     * 当vip用户输入了微信号时发送钉钉消息提醒运营人员进行处理
     */
    public static final String VIP_WRITE_WX_HANDEL = "VIP_WRITE_WX_HANDEL";

    /**
     * 推送消息失败钉钉报警
     */
    public static final String PUSH_MANAGER_JOB_ERROR = "PUSH_MANAGER_JOB_ERROR";

    /**
     * 首冲档位abtest
     */
    public static final String FIRST_CHARGE_ABTEST = "FIRST_CHARGE_ABTEST";

    /**
     * 首冲档位abtest开关
     */
    public static final String FIRST_CHARGE_SWITCH = "FIRST_CHARGE_SWITCH";

    /**
     * 出牌规则上线策略,只能同时跑一个策略
     */
    public static final String PLAY_CARD_STRATEGY_KEY = "PLAY_CARD_STRATEGY_KEY";

    /**
     * 翻牌文案汇总configkey
     */
    public static final String FLIP_CARD_TEXT = "FLIP_CARD_TEXT";
    /**
     * 游戏中用户快捷聊天
     */
    public static final String GAMEING_DIALOG_CONFIG="GAMEING_DIALOG_CONFIG";
    /**
     * 霸机首冲配置倒计时key
     */
    public static final String OCCUPY_COUNT_DOWN = "OCCUPY_COUNT_DOWN";
    /**
     * 娃娃列表页状态映射失败key
     */
    public static final String WAWA_LIST_STATUS_FAILD = "WAWA_LIST_STATUS_FAILD";

    /**
     * 娃娃详情页娃娃状态图片
     */
    public static final String WAWA_DETAIL_STATUS_IMAGE = "WAWA_DETAIL_STATUS_IMAGE";
}

==> wawa-service-common-0.0.38-20180716.111628-5-sources.jar: cn/com/wawa/common/constants/ConfigKeyConstants.java <==
package cn.com.wawa.common.constants;

public class ConfigKeyConstants {
    /**
     * 活动推送消息的活动id
     */
    public static final String ACTIVITY_JPUSH_ACTIVITYIDS = "ACTIVITY_JPUSH_ACTIVITYIDS";
    /**
     * 具体活动的推送规则和内容
     */
    public static final String ACTIVITY_JPUSH_CONFIG = "ACTIVITY_JPUSH_CONFIG_%s";
    /**
     * 娃娃订单详情中的领取规则
     */
    public static final String WAWA_RECEIVE_RULE = "WAWA_RECEIVE_RULE_%s";

    public static final String CAUGHT_BROADCAST_MSG = "CAUGHT_BROADCAST_MSG";

    public static final String HOME_POPUP_ACTIVITY = "HOME_POPUP_ACTIVITY";

    //消防群token
    public static final String WARN_RECIVER = "WARN_RECIVER";

    //风控报警群
    public static final String DINGDING_WARN_RISK = "DINGDING_WARN_RISK";

    public static final String MINE_OVERWRITTING_COLOR="MINE_OVERWRITTING_COLOR";

    public static final String MY_PAGE_OVERWRITING_COLOR = "MY_PAGE_OVERWRITING_COLOR";

    //ios审核用户id
    public static final String IOS_REVIEW_USERID="IOS_REVIEW_USERID";
    //ios审核用户token
    public static final String IOS_REVIEW_TOKEN="IOS_REVIEW_TOKEN";
    /**
     * 已发货的用户,不再展示红字部分规则
     */
    public static final String WAWA_RECEIVE_RULE_DELIVERY="WAWA_RECEIVE_RULE_DELIVERY";

    /**
     * 强抓不中送机会
     */
    public static final String STRONG_GRAB_CHANCE = "STRONG_GRAB_CHANCE";
    public static final String STRONG_GRAB_CHANCE_NEW = "STRONG_GRAB_CHANCE_NEW";
    /**
     * 背景音乐url
     */
    public static final String MUSIC_URL = "MUSIC_URL";

    /**
     * 娃娃机故障告警群token
     */
    public static final String WAWA_FAULT = "WAWA_FAULT";

    /**
     * 发货提示消息配置
     */
    public static final String DELIVERY_HINT = "DELIVERY_HINT";

    /**
     * 钉钉发货提示消息配置
     */
    public static final String ARWARD_DELIVERY = "ARWARD_DELIVERY";

    /**
     * 抓取失败原因(mq发送)
     */
    public static final String CAUGHT_FAIL_MSG = "CAUGHT_FAIL_MSG";
    /**
     * 娃娃机数量监控执行时间配置
     */
    public static final String WAWA_NUM_MONITOR_KEY = "WAWA_NUM_MONITOR_KEY";

    public static final String ACCOUNT_CHANGE_DETAIL_SHOW_SWITCH = "ACCOUNT_CHANGE_DETAIL_SHOW_SWITCH";

    public static final String CENTER_MSG_TYPE_PIC = "CENTER_MSG_TYPE_PIC_%s";

    public static final String APPEAL_REJECT_MSG = "APPEAL_REJECT_CENTER_MSG";
    public static final String APPEAL_JUDGE_CATCHED_MSG = "APPEAL_JUDGE_CATCHED_CENTER_MSG";
    public static final String APPEAL_RETURN_COIN_MSG = "APPEAL_RETURN_COIN_CENTER_MSG";
    public static final String APPEAL_ADD_WAWA_NUM_MSG = "APPEAL_ADD_WAWA_NUM_CENTER_MSG";
    public static final String APPEAL_OTHER_MSG = "APPEAL_OTHER_CENTER_MSG";
    public static final String RED_PACKAGE_WILL_EXPIRE_MSG = "RED_PACKAGE_WILL_EXPIRE_CENTER_MSG";
    public static final String DELIVERY_ALREADY_MSG_CONTENT = "DELIVERY_ALREADY_MSG_CONTENT";
    public static final String DELIVERY_SIGNIN_MSG_CONTENT = "DELIVERY_SIGNIN_MSG_CONTENT";

    /**
     * 拼团
     */
    public static final String GROUP_BOOK_JOIN_SUC_SMS = "GROUP_BOOK_JOIN_SUC_SMS";
    public static final String GROUP_BOOK_ALERT_SMS = "GROUP_BOOK_ALERT_SMS";
    public static final String GROUP_BOOK_SUC_SMS = "GROUP_BOOK_SUC_SMS";
    public static final String GROUP_BOOK_FAIL_SMS = "GROUP_BOOK_FAIL_SMS";
    public static final String GROUP_BOOK_NEW_USER_NO_APP_SMS = "GROUP_BOOK_NEW_USER_NO_APP_SMS";

    public static final String GROUP_BOOK_ALERT_CENTER_MSG = "GROUP_BOOK_ALERT_CENTER_MSG";
    public static final String GROUP_BOOK_SUC_CENTER_MSG = "GROUP_BOOK_SUC_CENTER_MSG";
    public static final String GROUP_BOOK_FAIL_CENTER_MSG = "GROUP_BOOK_FAIL_CENTER_MSG";

    public static final String GROUP_BOOK_SUC_JPUSH = "GROUP_BOOK_SUC_JPUSH";

    /**
     * 排行榜活动时间配置  临时
     */
    public static final String RANK_LIST = "RANK_LIST";

    public static final String RANK_AWARD_CENTER_MSG = "RANK_AWARD_CENTER_MSG";

    public static final String RANK_FLOOR_CONFIG = "RANK_FLOOR_CONFIG";

    /**
     * 失败后加积分版本
     */
    public static final String ADD_CREDITS_VERSION ="ADD_CREDITS_VERSION";

    public static final String ADD_CREDITS_CAUGHT_FAIL_MSG="ADD_CREDITS_CAUGHT_FAIL_MSG";

    public static final String FAST_DIALOG_CONFIG="FAST_DIALOG_CONFIG";

    /**
     * 充值送的红包的档位
     */
    public static final String GUARANTEE_V3_WAWA_CONFIG="GUARANTEE_V3_WAWA_CONFIG";
    /**
     * 卡展示规则
     */
    public static final String CARD_SHOW_RULE="CARD_SHOW_RULE";

    public static final String CARD_JPUSH_CONFIG = "CARD_JPUSH_CONFIG";
    public static final String CARD_FLOOR_CONFIG = "CARD_FLOOR_CONFIG";
    public static final String CARD_SHOW_EXPIRED_PIC = "CARD_SHOW_EXPIRED_PIC";

    public static final String GET_TITLE = "GET_TITLE";

    public static final String CONFIG_GMT_CREATE = "CONFIG_GMT_CREATE";

    public static final String WAWA_PAST_DUE = "WAWA_PAST_DUE";

    /**
     * 限时玩法
     */
    public static final String TIME_LIMIT_CONFIG = "TIME_LIMIT_CONFIG";
    public static final String CHARGE_ABTEST="CHARGE_ABTEST";

    /**
     * 限时玩法 风控规则
     */
    public static final String TIME_LIMIT_RISK_MANAGE = "TIME_LIMIT_RISK_MANAGE";

    /**
     * erp订单区分查询配置key
     */
    public static final String ERP_ORDER_SHOP_CONFIG = "ERP_ORDER_SHOP_CONFIG";

    public static final String FIRST_CHARGE_COUNTDOWN = "FIRST_CHARGE_COUNTDOWN";

    /**
     * 豪礼奖励系统消息模板
     */
    public static final String ACTIVITY_SOLID_AWARD_MSG = "ACTIVITY_SOLID_AWARD_MSG";
    public static final String ACTIVITY_DAILY_AWARD_MSG = "ACTIVITY_DAILY_AWARD_MSG";
    public static final String ACTIVITY_ACTIVE_AWARD_MSG = "ACTIVITY_ACTIVE_AWARD_MSG";

    /**
     * erp取消订单相关报警
     */
    public static final String ERP_CANCELL_MSG = "ERP_CANCELL_MSG";

    /**
     *vip等级晋升消息
     */
    public static final String VIP_PROMOTION_MSG = "VIP_PROMOTION_MSG";

    /**
     * h5分享帮抓娃娃站内信模版
     */
    public static final String H5_SHARE_CATCH_MSG = "H5_SHARE_CATCH_MSG";

    /**
     *vip等级晋升站内信中图片地址key值模板
     */
    public static final String VIP_PROMOTION_IMG = "VIP_PROMOTION_IMG_VIP%S";

    /**
     * 发送填写vip微信号站内信模板
     */
    public static final String WRITE_VIP_WXNO_MSG = "WRITE_VIP_WXNO_MSG";

    public static final String APPEAL_HANDLE_WARM_CONFIG = "APPEAL_HANDLE_WARM_CONFIG";

    /**
     * 游戏失败赠送乐豆奖励配置信息
     */
    public static final String REWARD_CREDIS_CONFIG = "REWARD_CREDIS_CONFIG";

    /**
     * 限时玩法-1v1  匹配场等级
     */
    public static final String TIME_LIMIT_PK_LEVEL = "TIME_LIMIT_PK_LEVEL";
    /**
     * 限时玩法-1v1  玩法介绍页
     */
    public static final String PK_1V1_IMG_CONFIG = "PK_1V1_IMG_CONFIG";

    public static final String ADD_COIN = "ADD_COIN";
    /**
     * 限时玩法-1v1  初级场金额
     */
    public static final String BATTLE_JUNIOR_PRICE = "BATTLE_JUNIOR_PRICE";

    /**
     * 限时pk玩法上线时间key,用于甄别 在上线时间之后的为新用户,需要走abtest逻辑
     */
    public static final String LIMIT_PK_ONLINE_TIME = "LIMIT_PK_ONLINE_TIME";

    /**
     * VIP专区所对应的分类id
     */
    public static final String VIP_CATEGORY_ID_CONFIG = "VIP_CATEGORY_ID_CONFIG";

    /**
     * 移动端充值url
     */
    public static final String MOBILE_PAY_URL = "MOBILE_PAY_URL";

    /**
     * vip等级特权：更多icon配置信息
     */
    public static final String VIP_MORE_PRIVILEGE_CONFIG = "VIP_MORE_PRIVILEGE_CONFIG";

    /**
     * vip等级特权九宫格请求地址配置信息
     */
    public static final String VIP_PRIVILEGE_DEC_H5_URL = "VIP_PRIVILEGE_DEC_H5_URL";

    /**
     * 当vip用户输入了微信号时发送钉钉消息提醒运营人员进行处理
     */
    public static final String VIP_WRITE_WX_HANDEL = "VIP_WRITE_WX_HANDEL";

    /**
     * 推送消息失败钉钉报警
     */
    public static final String PUSH_MANAGER_JOB_ERROR = "PUSH_MANAGER_JOB_ERROR";

    /**
     * 首冲档位abtest
     */
    public static final String FIRST_CHARGE_ABTEST = "FIRST_CHARGE_ABTEST";

    /**
     * 首冲档位abtest开关
     */
    public static final String FIRST_CHARGE_SWITCH = "FIRST_CHARGE_SWITCH";

    /**
     * 出牌规则上线策略,只能同时跑一个策略
     */
    public static final String PLAY_CARD_STRATEGY_KEY = "PLAY_CARD_STRATEGY_KEY";

    /**
     * 翻牌文案汇总configkey
     */
    public static final String FLIP_CARD_TEXT = "FLIP_CARD_TEXT";
    /**
     * 游戏中用户快捷聊天
     */
    public static final String GAMEING_DIALOG_CONFIG="GAMEING_DIALOG_CONFIG";
    /**
     * 霸机首冲配置倒计时key
     */
    public static final String OCCUPY_COUNT_DOWN = "OCCUPY_COUNT_DOWN";
    /**
     * 娃娃列表页状态映射失败key
     */
    public static final String WAWA_LIST_STATUS_FAILD = "WAWA_LIST_STATUS_FAILD";

    /**
     * 娃娃详情页娃娃状态图片
     */
    public static final String WAWA_DETAIL_STATUS_IMAGE = "WAWA_DETAIL_STATUS_IMAGE";
    /**
     * 限时玩法下线极光推送配置
     */
    public static final String LIMIT_DOWN_JPUSH_KEY = "LIMIT_DOWN_JPUSH_KEY";
    /**
     * 限时玩法下线站内信推送
     */
    public static final String LIMIT_DOWN_MAIL_KEY = "LIMIT_DOWN_MAIL_KEY";

    /**
     * 限时玩法下线极光推送开关
     */
    public static final String LIMIT_DOWN_JPUSH_SWITCH = "LIMIT_DOWN_JPUSH_SWITCH";
    /**
     * 限时玩法下线站内信推送开关
     */
    public static final String LIMIT_DOWN_MAIL_SWITCH = "LIMIT_DOWN_MAIL_SWITCH";

    /**
     * 推啊appSecret
     */
    public static final String CONFIG_KEY_APP_SECRET = "TUIA_APP_SECRET";

    /**
     * 推啊游戏大厅url
     */
    public static final String CONFIG_KEY_TUI_URL = "TUIA_GAME_URL";

    /**
     * 推啊游戏大厅 领金币图片
     */
    public static final String TUIA_GAME_COIN_IMG = "TUIA_GAME_COIN_IMG";

    /**
     * 分享奖励配置key
     */
    public static final String MSG_SHARE_DOWNLOAD_REWARD = "SHARE_DOWNLOAD_REWARD";
}
